summaryrefslogtreecommitdiffstats
path: root/Lib/hmac.py
diff options
context:
space:
mode:
authorMatthias Bussonnier <bussonniermatthias@gmail.com>2018-09-10 18:10:01 (GMT)
committerGregory P. Smith <greg@krypto.org>2018-09-10 18:10:01 (GMT)
commit51a4743d19abd016f0772a57fb31df7af9220e18 (patch)
treefee5036d3e6f4a700f40171b3c0480e2122d0e13 /Lib/hmac.py
parent78deb7f33227972987722bc3fed5bcb45fae869e (diff)
downloadcpython-51a4743d19abd016f0772a57fb31df7af9220e18.zip
cpython-51a4743d19abd016f0772a57fb31df7af9220e18.tar.gz
cpython-51a4743d19abd016f0772a57fb31df7af9220e18.tar.bz2
bpo-33604: Remove deprecated HMAC default value marked for removal in 3.8 (GH-7063)
HMAC's digestmod was deprecated marked for removal, this removes it as planned.
Diffstat (limited to 'Lib/hmac.py')
-rw-r--r--Lib/hmac.py13
1 files changed, 3 insertions, 10 deletions
diff --git a/Lib/hmac.py b/Lib/hmac.py
index 43b7212..890eaba 100644
--- a/Lib/hmac.py
+++ b/Lib/hmac.py
@@ -35,12 +35,9 @@ class HMAC:
key: key for the keyed hash object.
msg: Initial input for the hash, if provided.
digestmod: A module supporting PEP 247. *OR*
A hashlib constructor returning a new hash object. *OR*
A hash name suitable for hashlib.new().
- Defaults to hashlib.md5.
- Implicit default to hashlib.md5 is deprecated since Python
- 3.4 and will be removed in Python 3.8.
Note: key and msg must be a bytes or bytearray objects.
"""
@@ -49,11 +46,7 @@ class HMAC:
raise TypeError("key: expected bytes or bytearray, but got %r" % type(key).__name__)
if digestmod is None:
- _warnings.warn("HMAC() without an explicit digestmod argument "
- "is deprecated since Python 3.4, and will be removed "
- "in 3.8",
- DeprecationWarning, 2)
- digestmod = _hashlib.md5
+ raise ValueError('`digestmod` is required.')
if callable(digestmod):
self.digest_cons = digestmod
@@ -35,12 +35,9 @@ class HMAC:
key: key for the keyed hash object.
msg: Initial input for the hash, if provided.
- digestmod: A module supporting PEP 247. *OR*
- A hashlib constructor returning a new hash object. *OR*
+ digestmod: Required. A module supporting PEP 247. *OR*
+ A hashlib constructor returning a new hash object. *OR*
A hash name suitable for hashlib.new().